<?php

function ajax_auth_init() {
    wp_enqueue_script('ajax-auth-script', plugins_url('../../assets/js/ajax-auth-script.js', __FILE__), '1.0.0', '', true);
    wp_enqueue_script('ajax-auth-script');
    wp_localize_script('ajax-auth-script', 'ajax_auth_object', array(
        'ajaxurl' => admin_url('admin-ajax.php'),
        'redirecturl' => home_url(),
        'loadingmessage' => __('Sending user info, please wait...')
    ));
}

add_action('init', 'ajax_auth_init');


// Enable the user with no privileges to run ajax_login() in AJAX
add_action('wp_ajax_nopriv_ajaxlogin', 'ajax_login');
add_action('wp_ajax_ajaxlogin', 'ajax_login');
// Enable the user with no privileges to run ajax_register() in AJAX
add_action('wp_ajax_nopriv_ajaxregister', 'ajax_register');
add_action('wp_ajax_ajaxregister', 'ajax_register');

function ajax_login() {

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-login-nonce', 'security');

    // Nonce is checked, get the POST data and sign user on
    // Call auth_user_login
    auth_user_login($_POST['username'], $_POST['password'], 'Login');

    die();
}

function ajax_register() {

    // First check the nonce, if it fails the function will break
    check_ajax_referer('ajax-register-nonce', 'security');

    // Nonce is checked, get the POST data and sign user on
    $info = array();
    $info['user_nicename'] = $info['nickname'] = $info['display_name'] = $info['first_name'] = $info['user_login'] = sanitize_user($_POST['username']);
    $info['user_pass'] = sanitize_text_field($_POST['password']);
    $info['user_email'] = sanitize_email($_POST['email']);
    $info['role'] = sanitize_text_field($_POST['role']);
    // Register the user

    $user_register = wp_insert_user($info);

    if (is_wp_error($user_register)) {
        $error = $user_register->get_error_codes();

        if (in_array('empty_user_login', $error))
            echo json_encode(array('loggedin' => false, 'message' => __($user_register->get_error_message('empty_user_login'))));
        elseif (in_array('existing_user_login', $error))
            echo json_encode(array('loggedin' => false, 'message' => __('This username is already registered.', 'jxpress-portal')));
        elseif (in_array('existing_user_email', $error))
            echo json_encode(array('loggedin' => false, 'message' => __('This email address is already registered.', 'jxpress-portal')));
    } else {
        $candidate_email_data = jxpress_candidate_register_email_data($info);
        $employer_email_data = jxpress_employer_register_email_data($info);
        $admin_email_data = jxpress_admin_registration_email_data($info);
      
        if ($candidate_email_data['email'] && sanitize_text_field($_POST['role']) == 'candidate') {
            $email_subject = $candidate_email_data['subject'];
            $headers = 'From: ' . $candidate_email_data['from'] . "\r\n" .
                    'Reply-To: ' . $candidate_email_data['from'] . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
             wp_mail($candidate_email_data['email_to'], $email_subject, $candidate_email_data['message'], $headers);
             
        }
        if ($employer_email_data['email'] && sanitize_text_field($_POST['role']) == 'employer') {
            $email_subject = $employer_email_data['subject'];
            $headers = 'From: ' . $employer_email_data['from'] . "\r\n" .
                    'Reply-To: ' . $employer_email_data['from'] . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
             wp_mail($employer_email_data['email_to'], $email_subject, $employer_email_data['message'], $headers);
             
        }
        
        if ($admin_email_data['email']) {
            $email_subject = $admin_email_data['subject'];
            $headers = 'From: ' . $admin_email_data['from'] . "\r\n" .
                    'Reply-To: ' . $admin_email_data['from'] . "\r\n" .
                    'X-Mailer: PHP/' . phpversion();
             wp_mail($admin_email_data['email_to'], $email_subject, $admin_email_data['message'], $headers);
             
        }
        

        auth_user_login($info['nickname'], $info['user_pass'], 'Registration');
    }

    die();
}

function auth_user_login($user_login, $password, $login) {
    $info = array();
    $info['user_login'] = $user_login;
    $info['user_password'] = $password;
    $info['remember'] = true;

    $user_signon = wp_signon($info, ''); // From false to '' since v4.9
    if (is_wp_error($user_signon)) {
        echo json_encode(array('loggedin' => false, 'message' => __('Wrong username or password.', 'jxpress-portal')));
    } else {
        wp_set_current_user($user_signon->ID);
        echo json_encode(array('loggedin' => true, 'message' => __($login . ' successful, redirecting...', 'jxpress-portal')));
    }

    die();
}

add_action('wp_ajax_nopriv_jxpresspasswordrest', 'jxpress_retrieve_password');
add_action('wp_ajax_jxpresspasswordrest', 'jxpress_retrieve_password');

function jxpress_retrieve_password() {
    global $wpdb, $wp_hasher;
    $user_login = $_POST['user_login'];
    $user_login = sanitize_text_field($user_login);

    if (empty($user_login)) {
        echo json_encode(array('message' => __('Empty Username or E-mail', 'jxpress-portal')));
        die();
    } else if (strpos($user_login, '@')) {
        $user_data = get_user_by('email', trim($user_login));
        if (empty($user_data)) {
            echo json_encode(array('message' => __('E-mail not exist', 'jxpress-portal')));
            die();
        }
    } else {
        $login = trim($user_login);
        $user_data = get_user_by('login', $login);
    }

    do_action('lostpassword_post');


    if (!$user_data) {
        echo json_encode(array('message' => __('User not exist', 'jxpress-portal')));
        die();
    }

    // redefining user_login ensures we return the right case in the email
    $user_login = $user_data->user_login;
    $user_email = $user_data->user_email;

    do_action('retreive_password', $user_login);  // Misspelled and deprecated
    do_action('retrieve_password', $user_login);

    $allow = apply_filters('allow_password_reset', true, $user_data->ID);

    if (!$allow) {
        echo json_encode(array('message' => __('Something issue in password reset.', 'jxpress-portal')));
        die();
    } else if (is_wp_error($allow)) {
        echo json_encode(array('message' => __('Something issue in password reset.', 'jxpress-portal')));
        die();
    }


    $key = wp_generate_password(20, false);
    do_action('retrieve_password_key', $user_login, $key);

    if (empty($wp_hasher)) {
        require_once ABSPATH . 'wp-includes/class-phpass.php';
        $wp_hasher = new PasswordHash(8, true);
    }
    $hashed = $wp_hasher->HashPassword($key);
    $wpdb->update($wpdb->users, array('user_activation_key' => $hashed), array('user_login' => $user_login));

    $message = __('Someone requested that the password be reset for the following account:', 'jxpress-portal') . "\r\n\r\n";
    $message .= network_home_url('/') . "\r\n\r\n";
    $message .= sprintf(__('Username: %s'), $user_login) . "\r\n\r\n";
    $message .= __('If this was a mistake, just ignore this email and nothing will happen.', 'jxpress-portal') . "\r\n\r\n";
    $message .= __('To reset your password, visit the following address:', 'jxpress-portal') . "\r\n\r\n";
    $message .= '<' . network_site_url("wp-login.php?action=rp&key=$key&login=" . rawurlencode($user_login), 'login') . ">\r\n";

    if (is_multisite())
        $blogname = $GLOBALS['current_site']->site_name;
    else
        $blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

    $title = sprintf(__('[%s] Password Reset'), $blogname);

    $title = apply_filters('retrieve_password_title', $title);
    $message = apply_filters('retrieve_password_message', $message, $key);

    if ($message && !wp_mail($user_email, $title, $message)) {
        echo json_encode(array('message' => __('The e-mail could not be sent.', 'jxpress-portal')));
        die();
    }

    echo json_encode(array('message' => __('Link for password reset has been emailed to you. Please check your email.', 'jxpress-portal')));
    die();
}

add_shortcode('jxpresssignup', 'jxpress_signup');

function jxpress_signup($atts) {
    if (is_user_logged_in()) {
        return do_shortcode('[jxpressdashboard]');
    }
    extract(shortcode_atts(
                    array(
        'login' => 1,
        'register' => 1,
                    ), $atts));
    ob_start();
    ?>
    <div class="page-tab">
        <div class="form">
            <div class="userform">
                <ul class="nav nav-tabs nav-justified ml-0 jxpress-login-tabs" role="tablist">
                    <?php if ($login) { ?>
                        <li class="border nav-item"><a href="#login1" role="tab" data-toggle="tab" aria-expanded="true" class="nav-link border-0 active"><?php echo esc_html__('Log in', 'jxpress-portal'); ?></a></li>
                    <?php } ?>
                    <?php if ($register) { ?>
                        <li class="border nav-item"><a href="#signup" role="tab" data-toggle="tab" aria-expanded="false" class="nav-link border-0 <?php echo!$login ? "active" : ""; ?>"><?php echo esc_html__('Sign up', 'jxpress-portal'); ?></a></li>
                    <?php } ?>
                </ul>
                <div class="tab-content border border-top-0 p-3">
                    <?php if ($login) { ?>
                        <div class="tab-pane fade active show" id="login1">
                            <form id="login" class="ajax-auth" action="login" method="post">                                
                                <?php wp_nonce_field('ajax-login-nonce', 'security'); ?>  
                                <label for="username"><?php echo esc_html__('Username', 'jxpress-portal'); ?></label>
                                <input id="username" type="text" class="required" name="username">
                                <label for="password"><?php echo esc_html__('Password', 'jxpress-portal'); ?></label>
                                <input id="password" type="password" class="required" name="password">  
                                <input class="btn btn-larger btn-block mt-3" type="submit" value="<?php echo esc_html__('LOGIN', 'jxpress-portal'); ?>">   
                                <a  class="jxpress-login" href="#"><?php echo esc_html__('Lost Password', 'jxpress-portal'); ?></a>                            
                            </form>

                            <form name="lostpasswordform" id="lostpasswordform" action="<?php echo wp_lostpassword_url(); ?>" method="post" class="jxpress-lostpasswordform">                               
                                <label><?php echo esc_html__('Username or E-mail:', 'jxpress-portal'); ?></label>
                                <input type="text" name="user_login" id="user_login" class="input" value="" required="" size="20" tabindex="10">                                
                                <input type="submit" name="wp-submit" id="wp-submit" class="btn btn-larger btn-block mt-3" value="<?php echo esc_html__('Get New Password', 'jxpress-portal'); ?>" tabindex="100">
                                <a class="jxpress-lostpassword" href="#" ><?php echo esc_html__('Login here', 'jxpress-portal'); ?></a>                            

                            </form>

                        </div>
                    <?php } ?>
                    <?php if ($register) { ?>
                        <div class="tab-pane fade <?php echo!$login ? "active show" : ""; ?>" id="signup">
                            <form id="register" class="ajax-auth"  action="register" method="post">                               
                                <ul class="jxpress-role-tabs list-inline ml-0">
                                    <li class="active px-2 py-1 border list-inline-item" data-role="candidate">
                                        <a href="#" onclick="javascript:return false;"><i class="icon-user-add"></i>Candidate</a></li>
                                    <li class="list-inline-item px-2 py-1 border" data-role="employer">
                                        <a href="#" onclick="javascript:return false;"><i class="icon-briefcase4"></i>Employer</a>
                                    </li>
                                </ul>
                                <?php wp_nonce_field('ajax-register-nonce', 'signonsecurity'); ?> 
                                <input type="hidden" name="role" class="role" value="candidate"/> 
                                <label for="signonname"><?php echo esc_html__('Username', 'jxpress-portal'); ?></label>
                                <input id="signonname" type="text" name="signonname" class="required">
                                <label for="email1"><?php echo esc_html__('Email', 'jxpress-portal'); ?></label>
                                <input id="email1" type="text" class="required email" name="email">
                                <label for="signonpassword"><?php echo esc_html__('Password', 'jxpress-portal'); ?></label>
                                <input id="signonpassword" type="password" class="required" name="signonpassword" >
                                <label for="password2"><?php echo esc_html__('Confirm Password', 'jxpress-portal'); ?></label>
                                <input type="password" id="password2" class="required" name="password2">
                                <input class="btn btn-larger btn-block mt-3" type="submit" value="<?php echo esc_html__('SIGNUP', 'jxpress-portal'); ?>">
                            </form>
                        </div>
                    <?php } ?>
                </div>
            </div>
        </div>
    </div>
    <?php
    return ob_get_clean();
}

add_action('wp_footer', 'jxpress_login_register_popup');

function jxpress_login_register_popup() {
    ?>
    <div id="jxpress-login" class="modal fade" role="dialog">
        <div class="modal-dialog">

            <!-- Modal content-->
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title"><?php echo esc_html__('LOGIN', 'jxpress-portal'); ?></h4><a href="#" data-dismiss="modal"><i class="fa fa-times" aria-hidden="true"></i></a>
                </div>
                <div class="modal-body">
                    <?php echo do_shortcode('[jxpresssignup register=0]'); ?>
                </div>

            </div>

        </div>
    </div>

    <div id="jxpress-register" class="modal fade" role="dialog">
        <div class="modal-dialog">

            <!-- Modal content-->
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title"><?php echo esc_html__('SIGNUP', 'jxpress-portal'); ?></h4><a href="#" data-dismiss="modal"><i class="fa fa-times" aria-hidden="true"></i></a>
                </div>
                <div class="modal-body">
                    <?php echo do_shortcode('[jxpresssignup login=0]'); ?>
                </div>

            </div>

        </div>
    </div>


    <?php
}

;
