<?php

function jxpress_cart_has_plan() {
    global $woocommerce;
    $items = $woocommerce->cart->get_cart();
    $plan = false;
    foreach ($items as $item => $values) {
        if ($values['data']->product_type == "jxpress_job_plan") {

            $plan = true;
        }
    }

    return $plan;
}

add_action('woocommerce_product_query', 'jxpress_remove_plan_from_shop');

function jxpress_remove_plan_from_shop($q) {

    //get current loop query
    $taxonomy_query = $q->get('tax_query');

    //appends the grouped products condition
    $taxonomy_query['relation'] = 'AND';
    $taxonomy_query[] = array(
        'taxonomy' => 'product_type',
        'field' => 'slug',
        'terms' => 'jxpress_job_plan',
        'operator' => 'NOT IN'
    );
    $q->set('tax_query', $taxonomy_query);
}

add_filter('woocommerce_add_to_cart_validation', 'jxpress_only_one_in_cart', 99, 2);

function jxpress_only_one_in_cart($passed, $added_product_id) {
    global $woocommerce;
    $items = $woocommerce->cart->get_cart();
    $product = wc_get_product($added_product_id);
    if ($product->get_type() == "jxpress_job_plan") {
        wc_empty_cart();
    } else {
        foreach ($items as $item => $values) {
            if ($values['data']->product_type == "jxpress_job_plan") {

                WC()->cart->remove_cart_item($values['key']);
            }
        }
    }
    return $passed;
}

function jxpress_remove_all_quantity_fields($return, $product) {
    if ($product->get_type() == "jxpress_job_plan") {
        return true;
    }
}

add_filter('woocommerce_is_sold_individually', 'jxpress_remove_all_quantity_fields', 10, 2);

function jxpress_disable_shipping_calc_on_cart($show_shipping) {
    if (jxpress_cart_has_plan()) {
        add_filter('woocommerce_cart_needs_shipping_address', '__return_false');
        return false;
    }
    return $show_shipping;
}

add_filter('woocommerce_cart_ready_to_calc_shipping', 'jxpress_disable_shipping_calc_on_cart', 99);

function jxpress_wc_add_to_cart_message($message, $products) {
    // make filter magic happen here... 
    global $woocommerce;
    foreach (array_keys($products) as $product) {
        $product = wc_get_product($product);
        if ($product->get_type() == "jxpress_job_plan") {
            $message = "";
        }
    }
    return $message;
}

;

// add the filter 
add_filter('wc_add_to_cart_message_html', 'jxpress_wc_add_to_cart_message', 10, 2);

add_action('init', 'jxpress_role_checkout_field_check');

function jxpress_role_checkout_field_check() {
    if (!is_user_logged_in()) {
        //add_action('woocommerce_after_order_notes', 'jxpress_role_checkout_field');
    }
}

function jxpress_role_checkout_field($checkout) {
    $chosen = WC()->session->get('radio_chosen');
    $chosen = empty($chosen) ? WC()->checkout->get_value('user_role') : $chosen;
    $chosen = empty($chosen) ? 'candidate' : $chosen;

    echo '<div id="custom_checkout_field"><h2>' . __('Signup As', 'jxpress-portal') . '</h2>';

    woocommerce_form_field('user_role', array(
        'type' => 'radio',
        'options' => array(
            'candidate' => 'Candidate',
            'employer' => 'Employer'
        ),
        'default' => $chosen
            ), $chosen);

    echo '</div>';
}

add_action('woocommerce_thankyou', 'jxpress_redirectcustom_thankyou');

function jxpress_redirectcustom_thankyou($order_id) {
    $order = new WC_Order($order_id);
    $user = $order->get_user();
    if ($user) {
        $items = $order->get_items();
        foreach ($items as $item) {
            $product_id = $item->get_product_id();
            $title = get_the_title($product_id);
            $totaljob = get_post_meta($product_id, 'total_listing', true);
             $featured = get_post_meta($product_id, 'featured_listing', true);
            $expirydays = get_post_meta($product_id, 'listing_expire', true);
            $wpDateFormat = get_option('date_format');
            $expirydate = date($wpDateFormat, strtotime(date($wpDateFormat) . ' + ' . $expirydays . ' days'));
            $displaydays = get_post_meta($product_id, 'listing_days', true);
            $package = array('package_name' => $title,
                'transaction_id' => $order->get_transaction_id(),
                'order_id' => $order_id,
                'package_expire' => $expirydate,
                'package_listing' => $totaljob,
                'package_display_day' => $displaydays,
                'package_listing_added' => 0,
                'featured'=>$featured,
                'package_listing_remaining' => $totaljob,
            );
            $packagedetail = json_encode($package);
            add_user_meta($user->ID, 'user_package', $packagedetail);
        }
    }
    $account = get_option('jxpress_account');
    $url = get_permalink($account) . "?user_tab=packages";
    if ($order->status != 'failed') {
        wp_redirect($url);
        exit;
    }
}

function jxpress_billing_field_strings($translated_text, $text, $domain) {
    switch ($translated_text) {
        case 'Billing details' :
            $translated_text = __('',  'jxpress-portal');
            break;
        case 'Additional information' :
            $translated_text = __('', 'jxpress-portal');
            break;
    }
    return $translated_text;
}

add_filter('gettext', 'jxpress_billing_field_strings', 20, 3);


add_filter('woocommerce_checkout_fields', 'jxpress_remove_checkout_fields');

function jxpress_remove_checkout_fields($fields) {
    unset($fields['billing']['billing_company']);
    unset($fields['billing']['billing_first_name']);
    unset($fields['billing']['billing_last_name']);
    unset($fields['billing']['billing_company']);
    unset($fields['billing']['billing_address_1']);
    unset($fields['billing']['billing_address_2']);
    unset($fields['billing']['billing_city']);
    unset($fields['billing']['billing_postcode']);
    unset($fields['billing']['billing_country']);
    unset($fields['billing']['billing_state']);
    unset($fields['billing']['billing_phone']);
    unset($fields['order']['order_comments']);
    unset($fields['billing']['billing_email']);
    unset($fields['account']['account_username']);
    unset($fields['account']['account_password']);
    unset($fields['account']['account_password-2']);
    return $fields;
}

add_action('woocommerce_checkout_update_order_meta', 'jxpress_update_checkout_user_role');

function jxpress_update_checkout_user_role($order_id) {
    $user_id = get_post_meta($order_id, '_customer_user', true);
    if (isset($_POST['user_role']) && !empty($_POST['user_role'])) {
        $u = new WP_User($user_id);
        $u->set_role($_POST['user_role']);
    }
}
